<?php

class blogostrap_custom_Widget_About extends WP_Widget {

	/**
	 * Sets up the widgets name etc
	 */
	public function __construct() {
		$widget_ops = array( 
			'classname' => 'blogostrap_class_about',
			'description' => __( 'Display about text and button.', 'blogostrap' ),
		);
		parent::__construct( 'blogostrap_about', __( 'Blogostrap About', 'blogostrap' ), $widget_ops );
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {
		// outputs the content of the widget
			echo $args['before_widget'];
		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
		}
		?>
	    <div class="col-md-12 text-justify">
	      <p><?php if ( ! empty( $instance['blogostrap_content'] ) ) { echo $instance['blogostrap_content']; } ?></p>
	    </div>
	    <div class="col-md-12 text-left btn-widget-about">
	      <a href="<?php if ( ! empty( $instance['blogostrap_button_link'] ) ) { echo esc_url($instance['blogostrap_button_link']); } ?>"><div class="btn btn-default"><?php if ( ! empty( $instance['blogostrap_button_text'] ) ) { echo $instance['blogostrap_button_text'];} ?></div></a>
	    </div>	    		
		<?php
		echo $args['after_widget'];
	}

	/**
	 * Outputs the options form on admin
	 *
	 * @param array $instance The widget options
	 */
	public function form( $instance ) {
		// outputs the options form on admin
		$title = ! empty( $instance['title'] ) ? $instance['title'] : '';
		$blogostrap_content = ! empty( $instance['blogostrap_content'] ) ? $instance['blogostrap_content'] : '';
		$blogostrap_button_link = ! empty( $instance['blogostrap_button_link'] ) ? $instance['blogostrap_button_link'] : '';
		$blogostrap_button_text = ! empty( $instance['blogostrap_button_text'] ) ? $instance['blogostrap_button_text'] : '';
		?>
		<p>
		<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Title:', 'blogostrap' ); ?></label> 
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
		</p>
		<p>
		<label for="<?php echo esc_attr( $this->get_field_id( 'blogostrap_content' ) ); ?>"><?php _e( 'Content:', 'blogostrap' ); ?></label> 
		<textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'blogostrap_content' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'blogostrap_content' ) ); ?>" ><?php echo esc_attr( $blogostrap_content ); ?></textarea>
		</p>
		<p>
		<label for="<?php echo esc_attr( $this->get_field_id( 'blogostrap_button_text' ) ); ?>"><?php _e( 'Button text:', 'blogostrap' ); ?></label> 
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'blogostrap_button_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'blogostrap_button_text' ) ); ?>" type="text" value="<?php echo esc_attr( $blogostrap_button_text ); ?>">
		</p>						
		<p>
		<label for="<?php echo esc_attr( $this->get_field_id( 'blogostrap_button_link' ) ); ?>"><?php _e( 'Button link:', 'blogostrap' ); ?></label> 
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'blogostrap_button_link' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'blogostrap_button_link' ) ); ?>" type="text" value="<?php echo esc_attr( $blogostrap_button_link ); ?>">
		</p>
		<?php 	
	}

	/**
	 * Processing widget options on save
	 *
	 * @param array $new_instance The new options
	 * @param array $old_instance The previous options
	 */
	public function update( $new_instance, $old_instance ) {
		// processes widget options to be saved
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
		$instance['blogostrap_content'] = ( ! empty( $new_instance['blogostrap_content'] ) ) ? sanitize_textarea_field( $new_instance['blogostrap_content'] ) : '';
		$instance['blogostrap_button_link'] = ( ! empty( $new_instance['blogostrap_button_link'] ) ) ? sanitize_text_field( $new_instance['blogostrap_button_link'] ) : '';
		$instance['blogostrap_button_text'] = ( ! empty( $new_instance['blogostrap_button_text'] ) ) ? sanitize_text_field( $new_instance['blogostrap_button_text'] ) : '';

		return $instance;
	}
}




add_action( 'widgets_init', function(){
	register_widget( 'blogostrap_custom_Widget_About' );
});
?>